@@ -6,7 +6,7 @@ package Dist::Iller::Config::Author::CSSON;
 
 # ABSTRACT: Dist::Iller config
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0326';
+our $VERSION = '0.0327';
 
 use Moose;
 use namespace::autoclean;
@@ -51,7 +51,11 @@ has homepage => (
     lazy => 1,
     default => sub {
         my $self = shift;
-        $self->has_distribution_name ? sprintf 'https://metacpan.org/release/%s', $self->distribution_name : undef;
+        my $distribution_name = $self->global && $self->global->has_distribution_name ? $self->global->distribution_name
+                              : $self->has_distribution_name ? $self->distribution_name
+                              : undef
+                              ;
+        return $distribution_name ? sprintf 'https://metacpan.org/release/%s', $distribution_name : undef;
     },
     documentation_default => q{https://metacpan.org/release/[distribution_name]},
     documentation => q{URL to the distribution's homepage.},
@@ -157,16 +161,15 @@ Dist::Iller::Config::Author::CSSON - Dist::Iller config
 
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
-<a href="http://cpants.cpanauthors.org/release/CSSON/Dist-Iller-Config-Author-CSSON-0.0326"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Dist-Iller-Config-Author-CSSON/0.0326" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Dist-Iller-Config-Author-CSSON%200.0326"><img src="http://badgedepot.code301.com/badge/cpantesters/Dist-Iller-Config-Author-CSSON/0.0326" alt="CPAN Testers result" /></a>
-<img src="https://img.shields.io/badge/coverage-42.7%-red.svg" alt="coverage 42.7%" />
+<a href="http://cpants.cpanauthors.org/release/CSSON/Dist-Iller-Config-Author-CSSON-0.0327"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Dist-Iller-Config-Author-CSSON/0.0327" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Iller-Config-Author-CSSON%200.0327"><img src="http://badgedepot.code301.com/badge/cpantesters/Dist-Iller-Config-Author-CSSON/0.0327" alt="CPAN Testers result" /></a>
 </p>
 
 =end html
 
 =head1 VERSION
 
-Version 0.0326, released 2020-12-15.
+Version 0.0327, released 2020-12-27.
 
 
 
@@ -546,6 +549,36 @@ Dist::Iller::Config::Author::Csson is a L<Dist::Iller> configuration. The plugin
 
 =end markdown
 
+=head2 global
+
+=begin HTML
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">Maybe[<a href='https://metacpan.org/pod/Types::Standard#InstanceOf'>InstanceOf</a>['Dist::Iller::DocType::Global']]</td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional</td>
+    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
+</tr>
+</table>
+
+<p></p>
+
+=end HTML
+
+=begin markdown
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">Maybe[<a href='https://metacpan.org/pod/Types::Standard#InstanceOf'>InstanceOf</a>['Dist::Iller::DocType::Global']]</td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional</td>
+    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
+</tr>
+</table>
+
+<p></p>
+
+=end markdown
+
 =head1 ENVIRONMENT VARIABLES
 
 =head2 FAKE_RELEASE
